@@ -484,7 +484,9 @@ class SAMLAuthBase(HanskenAuthBase):
     def do_saml_response(self, saml_response, response_consumer_url):
         log.debug('posting SAML response back to {sp}', sp=response_consumer_url)
         saml_response = self.session.post(response_consumer_url,
-                                          headers={'Content-Type': 'application/vnd.paos+xml'},
+                                          headers={'Content-Type': 'application/vnd.paos+xml',
+                                                   # we won't be using the actual response content, accept any content
+                                                   'Accept': '*/*'},
                                           data=saml_response,
                                           # following the redirect won't help us a lot, request method is lost
                                           allow_redirects=False)
@@ -496,8 +498,6 @@ class SAMLAuthBase(HanskenAuthBase):
                                    'expected a redirect'.format(response=saml_response),
                                    response=saml_response)
 
-        return saml_response
-
     def __call__(self, request):
         # in case there's a SAML exchange in progress, block requests from other sources until auth has been handled
         # self._lock is reentrant, so the active exchange will not be blocked
