@@ -1,10 +1,9 @@
 # encoding=utf-8
-
 from concurrent.futures import as_completed, FIRST_COMPLETED, ThreadPoolExecutor, wait
 import csv
 from functools import partial
 from io import open  # this is essentially meaningless, but makes it possible to mock calls to open()
-from os import makedirs, path
+from os import makedirs, path, PathLike
 import re
 
 from logbook import Logger
@@ -238,14 +237,11 @@ def to_csv(traces, output, fields,
             for item in fields:
                 yield from expand(item)
 
-    # will use builtin csv module, open the file in text mode, *don't* translate line endings to os default
-    # (by supplying lineterminator to the writer, a script would produce identical output on any os)
-    output = open(output, 'w', newline='', encoding=encoding)
-
     # resolve any 'automatic headers' passed as type_fields instances, split fields names and field 'pointers'
     names, fields = zip(*expand(fields))
-    with output:
-        writer = csv.DictWriter(output,
+
+    def do_write(writable):
+        writer = csv.DictWriter(writable,
                                 fieldnames=names,
                                 delimiter=delimiter,
                                 lineterminator=lineterminator,
@@ -254,6 +250,16 @@ def to_csv(traces, output, fields,
         for trace in traces:
             writer.writerow(to_dict(trace=trace, fields=fields))
 
+    # check the output argument, either 'openable' (path literal or PathLike) or assumed writable
+    if isinstance(output, (str, bytes, PathLike)):
+        # will use builtin csv module, open the file in text mode, *don't* translate line endings to os default
+        # (by supplying lineterminator to the writer, a script would produce identical output on any os)
+        with open(output, 'w', newline='', encoding=encoding) as output:
+            do_write(output)
+    else:
+        # treat output as a writable, don't close it when done
+        do_write(output)
+
 
 def to_file(trace, output, stream='raw', offset=0, size=None, key=fetch, bufsize=1 << 20):
     """
